<?php
/**
*
* @package phpBB3 Sidebar
* @version $Id$
* @copyright (c) 2011 Pico
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

$user->add_lang('mods/sidebar');

//  avatars
if (!function_exists('get_user_avatar'))
{
	include($phpbb_root_path . 'includes/functions_display.' . $phpEx);
}

//Latest topics
if ($config['sidebar_latesttopics'] && $user->optionget('sidebar_latesttopics'))
{
	global $auth, $cache, $user, $db, $phpbb_root_path, $phpEx, $template;

	// Get a list of forums the user cannot read
	$forum_array = array_unique(array_keys($auth->acl_getf('!f_read', true)));

	// We have auths, change the sql query below
	$sql_and = '';
	if (sizeof($forum_array))
	{
		$sql_and = ' AND ' . $db->sql_in_set('t.forum_id', $forum_array, true);
	}

	// Grab all topics that meet criteria and auths
	$sql_ary = array(
		'SELECT'	=> 'u.user_avatar, u.user_avatar_type, u.user_avatar_width, u.user_avatar_height, t.topic_id, t.forum_id, t.topic_title, t.topic_poster, t.topic_time, t.topic_first_poster_name, t.topic_first_poster_colour',
		'FROM'		=> array(TOPICS_TABLE => 't'),
		'LEFT_JOIN'	=> array(
			array(
				'FROM'	=> array(USERS_TABLE => 'u'),
				'ON'	=> 't.topic_poster = u.user_id',
   			),
		),
		'WHERE'		=> 't.topic_approved = 1 AND t.topic_status <> ' . ITEM_MOVED . ' ' . $sql_and,
		'ORDER_BY'	=> 't.topic_time DESC',
	);

	$result = $db->sql_query_limit($db->sql_build_query('SELECT', $sql_ary), $config['sidebar_positions']);
	$is_row = false;
    while( $row = $db->sql_fetchrow($result) )
    {
		$is_row = true;
		$view_topic_url = append_sid("{$phpbb_root_path}viewtopic.$phpEx", 'f=' . $row['forum_id'] . '&amp;t=' . $row['topic_id']);
		$topic_title = censor_text($row['topic_title']);
		$sidebar_avatar = $row['user_avatar'] ? get_user_avatar($row['user_avatar'], $row['user_avatar_type'], ($row['user_avatar_width'] > $row['user_avatar_height']) ? 35 : (35 / $row['user_avatar_height']) * $row['user_avatar_width'], ($row['user_avatar_height'] > $row['user_avatar_width']) ? 35 : (35 / $row['user_avatar_width']) * $row['user_avatar_height']) : '';
			
       	$template->assign_block_vars('latest_topics',array(
       		'U_TOPIC' 			=> $view_topic_url,
       		'TOPIC_AUTHOR_FULL'	=> get_username_string('full', $row['topic_poster'], $row['topic_first_poster_name'], $row['topic_first_poster_colour']),
			'SIDEBAR_AVATAR'	=> $sidebar_avatar,
			'U_VIEWPROFILE'		=> ($row['topic_poster'] != ANONYMOUS) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", 'mode=viewprofile&amp;u=' . $row['topic_poster']) : '',
			'TOPIC_TIME'		=> $user->format_date($row['topic_time']),
       		'TOPIC_TITLE' 		=> $topic_title));
    }

    $db->sql_freeresult($result);

	// If user doesn't have permission to read any forums, show a message
	if (!$is_row)
	{
		$template->assign_block_vars('latest_topics', array(
			'NO_TOPICS'	=> $user->lang['NO_TOPICS'],
		));
	}
}

//Latest posts
if ($config['sidebar_latestposts'] && $user->optionget('sidebar_latestposts'))
{
	global $auth, $cache, $user, $db, $phpbb_root_path, $phpEx, $template;

	// Get a list of forums the user cannot read
	$forum_array = array_unique(array_keys($auth->acl_getf('!f_read', true)));

	// We have auths, change the sql query below
	$sql_and = '';
	if (sizeof($forum_array))
	{
		$sql_and = ' AND ' . $db->sql_in_set('p.forum_id', $forum_array, true);
	}

	// Grab all posts that meet criteria and auths
	$sql_ary = array(
		'SELECT'	=> 'u.username, u.user_colour, u.user_avatar, u.user_avatar_type, u.user_avatar_width, u.user_avatar_height, p.post_id, p.forum_id, p.poster_id, p.post_time, p.post_username, p.post_subject',
		'FROM'		=> array(POSTS_TABLE => 'p'),
		'LEFT_JOIN'	=> array(
			array(
				'FROM'	=> array(USERS_TABLE => 'u'),
				'ON'	=> 'p.poster_id = u.user_id',
   			),
		),
		'WHERE'		=> 'p.post_approved = 1' . $sql_and,
		'ORDER_BY'	=> 'p.post_time DESC',
	);

	$result = $db->sql_query_limit($db->sql_build_query('SELECT', $sql_ary), $config['sidebar_positions']);
	$is_row = false;
    while( $row = $db->sql_fetchrow($result) )
    {
		$is_row = true;
		$view_post_url = append_sid("{$phpbb_root_path}viewtopic.$phpEx", 'f=' . $row['forum_id'] . '&amp;p=' . $row['post_id'] . '#p' . $row['post_id']);
		$post_title = censor_text($row['post_subject']);
		$sidebar_avatar = $row['user_avatar'] ? get_user_avatar($row['user_avatar'], $row['user_avatar_type'], ($row['user_avatar_width'] > $row['user_avatar_height']) ? 35 : (35 / $row['user_avatar_height']) * $row['user_avatar_width'], ($row['user_avatar_height'] > $row['user_avatar_width']) ? 35 : (35 / $row['user_avatar_width']) * $row['user_avatar_height']) : '';
			
       	$template->assign_block_vars('latest_posts',array(
       		'U_POST' 			=> $view_post_url,
       		'USERNAME_FULL'		=> get_username_string('full', $row['poster_id'], $row['username'], $row['user_colour']),
			'SIDEBAR_AVATAR'	=> $sidebar_avatar,
			'U_VIEWPROFILE'		=> ($row['poster_id'] != ANONYMOUS) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", 'mode=viewprofile&amp;u=' . $row['poster_id']) : '',
			'LAST_POST_TIME'	=> $user->format_date($row['post_time']),
       		'POST_TITLE' 		=> $post_title));
    }

    $db->sql_freeresult($result);

	// If user doesn't have permission to read any forums, show a message
	if (!$is_row)
	{
		$template->assign_block_vars('latest_posts', array(
			'NO_POSTS'	=> $user->lang['NO_POSTS'],
		));
	}
}

//Bookmarks
if ($config['sidebar_bookmarks'] && $config['allow_bookmarks'] && $user->data['is_registered'] && $user->optionget('sidebar_bookmarks'))
{
	global $auth, $cache, $user, $db, $phpbb_root_path, $phpEx, $template;

	// Get a list of forums the user cannot read
	$forum_array = array_unique(array_keys($auth->acl_getf('!f_read', true)));

	// We have auths, change the sql query below
	$sql_and = '';
	if (sizeof($forum_array))
	{
		$sql_and = ' AND ' . $db->sql_in_set('t.forum_id', $forum_array, true);
	}

	// Grab all bookmarks
	$sql_ary = array(
		'SELECT'	=> 'u.user_avatar, u.user_avatar_type, u.user_avatar_width, u.user_avatar_height, t.topic_id, t.forum_id, t.topic_title, t.topic_poster, t.topic_time, t.topic_first_poster_name, t.topic_first_poster_colour, b.topic_id',
		'FROM'		=> array(BOOKMARKS_TABLE => 'b'),
		'LEFT_JOIN'	=> array(
			array(
				'FROM'	=> array(TOPICS_TABLE => 't'),
				'ON'	=> 'b.topic_id = t.topic_id',
   			),
			array(
				'FROM'	=> array(USERS_TABLE => 'u'),
				'ON'	=> 't.topic_poster = u.user_id',
   			),
		),
		'WHERE'		=> 'b.user_id = ' . $user->data['user_id'] . ' '. $sql_and,
		'ORDER_BY'	=> 't.topic_last_post_time DESC',
	);

	$result = $db->sql_query($db->sql_build_query('SELECT', $sql_ary));
	$is_row = false;
    while( $row = $db->sql_fetchrow($result) )
    {
		$is_row = true;
		$view_topic_url = append_sid("{$phpbb_root_path}viewtopic.$phpEx", 'f=' . $row['forum_id'] . '&amp;t=' . $row['topic_id']);
		$topic_title = censor_text($row['topic_title']);
		$sidebar_avatar = $row['user_avatar'] ? get_user_avatar($row['user_avatar'], $row['user_avatar_type'], ($row['user_avatar_width'] > $row['user_avatar_height']) ? 35 : (35 / $row['user_avatar_height']) * $row['user_avatar_width'], ($row['user_avatar_height'] > $row['user_avatar_width']) ? 35 : (35 / $row['user_avatar_width']) * $row['user_avatar_height']) : '';
			
       	$template->assign_block_vars('bookmarks',array(
       		'U_BOOKMARKS'		=> $view_topic_url,
       		'USERNAME_FULL'		=> get_username_string('full', $row['topic_poster'], $row['topic_first_poster_name'], $row['topic_first_poster_colour']),
			'SIDEBAR_AVATAR'	=> $sidebar_avatar,
			'U_VIEWPROFILE'		=> ($row['topic_poster'] != ANONYMOUS) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", 'mode=viewprofile&amp;u=' . $row['topic_poster']) : '',
			'TOPIC_TIME'		=> $user->format_date($row['topic_time']),
       		'TOPIC_TITLE' 		=> $topic_title));
    }

    $db->sql_freeresult($result);

	// If user doesn't have permission to read any forums, show a message
	if (!$is_row)
	{
		$template->assign_block_vars('bookmarks', array(
			'NO_BOOKMARKS'	=> $user->lang['NO_BOOKMARKS'],
		));
	}
}

//Watched topics
if ($config['sidebar_watchedtopics'] && $config['allow_topic_notify'] && $user->data['is_registered']  && $user->optionget('sidebar_watchedtopics'))
{
	global $auth, $cache, $user, $db, $phpbb_root_path, $phpEx, $template;

	// Get a list of forums the user cannot read
	$forum_array = array_unique(array_keys($auth->acl_getf('!f_read', true)));

	// We have auths, change the sql query below
	$sql_and = '';
	if (sizeof($forum_array))
	{
		$sql_and = ' AND ' . $db->sql_in_set('t.forum_id', $forum_array, true);
	}

	// Grab all watched topics
	$sql_ary = array(
		'SELECT'	=> 'u.user_avatar, u.user_avatar_type, u.user_avatar_width, u.user_avatar_height, t.topic_id, t.forum_id, t.topic_title, t.topic_poster, t.topic_time, t.topic_first_poster_name, t.topic_first_poster_colour, tw.topic_id',
		'FROM'		=> array(
					TOPICS_WATCH_TABLE	=> 'tw',
					TOPICS_TABLE		=> 't'
				),
		'LEFT_JOIN'	=> array(
			array(
				'FROM'	=> array(USERS_TABLE => 'u'),
				'ON'	=> 't.topic_poster = u.user_id',
   			),
		),
		'WHERE'		=> 'tw.user_id = ' . $user->data['user_id'] . ' '. $sql_and . ' AND t.topic_id = tw.topic_id',
		'ORDER_BY'	=> 't.topic_last_post_time DESC',
	);

	$result = $db->sql_query($db->sql_build_query('SELECT', $sql_ary));
	$is_row = false;
    while( $row = $db->sql_fetchrow($result) )
    {
		$is_row = true;
		$view_topic_url = append_sid("{$phpbb_root_path}viewtopic.$phpEx", 'f=' . $row['forum_id'] . '&amp;t=' . $row['topic_id']);
		$topic_title = censor_text($row['topic_title']);
		$sidebar_avatar = $row['user_avatar'] ? get_user_avatar($row['user_avatar'], $row['user_avatar_type'], ($row['user_avatar_width'] > $row['user_avatar_height']) ? 35 : (35 / $row['user_avatar_height']) * $row['user_avatar_width'], ($row['user_avatar_height'] > $row['user_avatar_width']) ? 35 : (35 / $row['user_avatar_width']) * $row['user_avatar_height']) : '';
			
       	$template->assign_block_vars('watched_topics',array(
       		'U_BOOKMARKS'		=> $view_topic_url,
       		'USERNAME_FULL'		=> get_username_string('full', $row['topic_poster'], $row['topic_first_poster_name'], $row['topic_first_poster_colour']),
			'SIDEBAR_AVATAR'	=> $sidebar_avatar,
			'U_VIEWPROFILE'		=> ($row['topic_poster'] != ANONYMOUS) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", 'mode=viewprofile&amp;u=' . $row['topic_poster']) : '',
			'TOPIC_TIME'		=> $user->format_date($row['topic_time']),
       		'TOPIC_TITLE' 		=> $topic_title));
    }

    $db->sql_freeresult($result);

	// If user doesn't have permission to read any forums, show a message
	if (!$is_row)
	{
		$template->assign_block_vars('watched_topics', array(
			'NO_WATCHED_TOPICS'	=> $user->lang['NO_WATCHED_TOPICS'],
		));
	}
}

// Assign sidebar specific vars
$template->assign_vars(array(
	'S_DISPLAY_LATEST_TOPICS'	=> ($config['sidebar_latesttopics'] &&  $user->optionget('sidebar_latesttopics')) ? true : false,
	'S_DISPLAY_LATEST_POSTS'	=> ($config['sidebar_latestposts'] &&  $user->optionget('sidebar_latestposts')) ? true : false,
	'S_DISPLAY_BOOKMARKS'		=> ($config['sidebar_bookmarks'] && $config['allow_bookmarks'] && $user->data['is_registered'] &&  $user->optionget('sidebar_bookmarks')) ? true : false,
	'S_DISPLAY_WATCHED_TOPCS'	=> ($config['sidebar_watchedtopics'] && $config['allow_topic_notify'] && $user->data['is_registered'] &&  $user->optionget('sidebar_watchedtopics')) ? true : false,
	'S_DISPLAY_AVATARS'			=> ($config['sidebar_avatars'] &&  $user->optionget('sidebar_avatars')) ? true : false,
));

$template->set_filenames(array(
	'body' => 'sidebar.html')
);

?>